package TestCGIBin;

use Catalyst::Runtime '5.70';
use parent 'Catalyst';

__PACKAGE__->setup(qw/Static::Simple/);

1;
